@@ -49,6 +49,10 @@ type Policy struct {
 	// policy git url and branch
 	RepoURL string `toml:"repo_url,omitempty" yaml:"repo_url,omitempty"`
 	Branch  string `toml:"branch,omitempty" yaml:"branch,omitempty"`
+
+	// policy environment and access token
+	Environment string `toml:"environment,omitempty" yaml:"environment,omitempty"`
+	AccessToken string `toml:"access_token,omitempty" yaml:"access_token,omitempty"`
 }
 
 // Notifier represent a single notification in the terrascan config file
