@@ -32,7 +32,9 @@ import (
 	"github.com/hashicorp/go-multierror"
 )
 
-const iacFile = "IAC file"
+const (
+	iacFile = "IAC file"
+)
 
 // LoadIacDir loads all ARM template files in the current directory.
 func (a *ARMV1) LoadIacDir(absRootDir string, options map[string]interface{}) (output.AllResourceConfigs, error) {
@@ -47,6 +49,11 @@ func (a *ARMV1) LoadIacDir(absRootDir string, options map[string]interface{}) (o
 		return allResourcesConfig, multierror.Append(a.errIacLoadDirs, results.DirScanErr{IacType: "arm", Directory: absRootDir, ErrMessage: err.Error()})
 	}
 
+	if len(fileMap) == 0 {
+		errMsg := fmt.Sprintf("ARM files not found in the directory %s", a.absRootDir)
+		return allResourcesConfig, multierror.Append(a.errIacLoadDirs, results.DirScanErr{IacType: "arm", Directory: a.absRootDir, ErrMessage: errMsg})
+	}
+
 	for fileDir, files := range fileMap {
 		for i := range files {
 			// continue if file is a *.parameters.json or metadata.json
@@ -144,3 +151,8 @@ func (a *ARMV1) extractParameterValues(params map[string]interface{}) error {
 	}
 	return nil
 }
+
+// Name returns name of the provider
+func (a *ARMV1) Name() string {
+	return "arm"
+}
