@@ -28,3 +28,8 @@ import (
 func (tfv14 *TfV14) LoadIacDir(absRootDir string, options map[string]interface{}) (allResourcesConfig output.AllResourceConfigs, err error) {
 	return commons.NewTerraformDirectoryLoader(absRootDir, options).LoadIacDir()
 }
+
+// Name returns name of the provider
+func (*TfV14) Name() string {
+	return "terraform"
+}
