@@ -31,3 +31,8 @@ var (
 func (k *TFPlan) LoadIacDir(absRootDir string, options map[string]interface{}) (output.AllResourceConfigs, error) {
 	return output.AllResourceConfigs{}, errIacDirNotSupport
 }
+
+// Name returns name of the provider
+func (*TFPlan) Name() string {
+	return "tfplan"
+}
