@@ -66,17 +66,21 @@ func GetIamUserConfig(i *iam.User) []AWSResourceConfig {
 		},
 	})
 
+	iamLoginProfileConfig := IamUserLoginProfileConfig{
+		Config: Config{
+			Name: i.UserName,
+		},
+	}
+	if i.LoginProfile != nil {
+		iamLoginProfileConfig.PasswordResetRequired = i.LoginProfile.PasswordResetRequired
+	}
+
 	// add aws_iam_user_login_profile
 	resourceConfigs = append(resourceConfigs, AWSResourceConfig{
 		Type:     IamUserLoginProfile,
 		Name:     i.UserName,
 		Metadata: i.AWSCloudFormationMetadata,
-		Resource: IamUserLoginProfileConfig{
-			Config: Config{
-				Name: i.UserName,
-			},
-			PasswordResetRequired: i.LoginProfile.PasswordResetRequired,
-		},
+		Resource: iamLoginProfileConfig,
 	})
 
 	// add aws_iam_user_policy
